# Nonlinear data fitting using Least Squares
# Curve to fit:
#    f(x) = a*x^2 + b*x + c
# plus we know that the problem should be convex & increasing for x>=0
# thus we have additional constraints:
#    a>=0
#    b>=0 (from -b/2a<=0)
#
# last update: 27/9/2010 by JF
#

param n >= 1;           # number of measurement points
param m >= 1;           # number of data sets
param xpts{1..n};       # measurement points (x_i)
param D{1..n,1..m};     # Data to fit y^k_i 


var a;
var b;
var c;
var alpha;       # maximal error of the fit for a data set

minimize obj: alpha;

subject to err {j in 1..m}: 
   sum{i in 1..n} (a*xpts[i]^2 + b*xpts[i] +c - D[i,j])^2 <= alpha;

subject to constr1:  a>=0;
subject to constr2:  b>=0;

